<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Çeşitli kullanışlı ayarlamaları uygulamak için arayüz</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>brightness-systray’i başlatır</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>ekran sekmesi açık olarak açılır. Yalnızca Xfce masaüstü çalışırken geçerlidir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Doğrudan tema sekmesini açar. Xfce &amp; Fluxbox masaüstlerinde geçerlidir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Diğer sekmesini doğrudan açar. Tüm masaüstlerinde geçerli</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ana Pencere</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Yazılım (xrandr) Parlaklığı</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Metin Etiketi</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Donanım Arka Işığı</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-İnce Ayar</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="86"/>
        <location filename="../defaultlook.cpp" line="651"/>
        <location filename="../defaultlook.cpp" line="670"/>
        <location filename="../defaultlook.cpp" line="679"/>
        <location filename="../defaultlook.cpp" line="726"/>
        <location filename="../defaultlook.cpp" line="734"/>
        <location filename="../defaultlook.cpp" line="761"/>
        <location filename="../defaultlook.cpp" line="764"/>
        <source>MX Tweak</source>
        <translation>MX İnce ayar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paneli özelleştirme&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pencere davranışı ve kısayolları yapılandırma&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>Pencere Yöneticisi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Masaüstünüzün görünümünü özelleştirin&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>Görünüş</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>Xfce Ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Paneli yatay olarak göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Hacim</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tüm panelleri etkiler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1725"/>
        <source>Bottom</source>
        <translation>En alt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1735"/>
        <source>Top</source>
        <translation>En üst</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Görev listesi&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Paneli dikey olarak göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>1. paneli etkiler</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Eklenti Ölçekleri&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Şimdiki panel yapılandırmasını yedekle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Güç Yöneticisi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Yedek panel yapılandırmasını geri yükle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Ölçekleri Ayarla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1730"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1740"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pencere Düğmeleri&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike, panel için modern dock eklentisidir. Pencere Düğmeleri, yuva özellikleri olmayan klasik görev listesidir.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="630"/>
        <location filename="../defaultlook.ui" line="889"/>
        <location filename="../defaultlook.ui" line="1057"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <location filename="../defaultlook.ui" line="1283"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <location filename="../defaultlook.ui" line="1890"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Öntanımlı panele geri dön</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Görev Listesi eklentisini şu şekilde ayarlayın:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="596"/>
        <source>Theme Options</source>
        <translation>Tema Seçenekleri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Remove User Theme Set</source>
        <translation>Kullanıcı Temasını Kaldır</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>Preview</source>
        <translation>Önizleme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="656"/>
        <source>Undo</source>
        <translation>Gerial</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Mevcut Ayarları Tema Olarak Kaydet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="687"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;İmleçler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pencere Yöneticisi&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="704"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Uygulama&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="711"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Simgeler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="728"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Temalar&lt;/span&gt;&lt;p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="749"/>
        <source>Transparency and shadow options</source>
        <translation>Saydamlık ve gölge seçenekleri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>compton.conf dosyasını doğrudan metin düzenleyicide düzenleyin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="766"/>
        <source>Edit compton.conf</source>
        <translation>compton.conf’u düzenle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Ayarları&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="780"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;VBlank kipini değiştirmek, bazı ekran yırtılma sorunlarını hafifletmeye yardımcı olabilir. Daha fazla bilgi için Yardım’a bakın.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="794"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>compton-conf yapılandırma aracını başlat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="804"/>
        <source>Compton settings</source>
        <translation>Compton ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="828"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>auto</source>
        <translation>oto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="852"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="857"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>kapalı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="912"/>
        <source>Display</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Donanım Arka Işığı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;İnce Ayarı Göster&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="957"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Xrandr ince ayarları için Görüntüleme Seçimi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Resolution</source>
        <translation>Çözünürlük</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ekran başına kazanç&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Yazılım (xrandr) Parlaklığı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <location filename="../defaultlook.ui" line="1088"/>
        <source>TextLabel</source>
        <translation>Metin Etiketi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>GTK ölçeği</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>xrandr Ölçekleme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1114"/>
        <source>Config Options</source>
        <translation>Yapılandırma Seçenekleri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Masaüstünde uzun dosya adlarının kısaltılmasını devre dışı bırak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   not: uyku için, takas &gt;= RAM olması gereklidir.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Enable single-click on desktop</source>
        <translation>Masaüstünde tek tık etkin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Oturumu Kapat menüsünde hazırda bekletme kipini etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Thunar özel sağ tıklama eylemlerini sistem varsayılanlarına sıfırlama</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Thunar Dosya Yöneticisinde tek tık etkin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Thunar windows always open in split view</source>
        <translation>Thunar pencereleri her zaman bölünmüş görünümde açılır</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Thunar bölünmüş görünüm yatay açılır</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mevcut ise bildirimlerde yüzdeleri göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Enable Desktop Zoom </source>
        <translation>Masaüstü Yakınlaştırmayı Etkinleştir </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <location filename="../defaultlook.ui" line="1815"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Tüm çalışma alanlarındaki pencereleri panelde göster.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>İletişim kutularının altında GTK Dosya İletişim Kutusu eylem düğmelerini göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(ayrıca Xfce uygulamaları için İstemci Tarafı Süslemelerini kapatır)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Panel Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1264"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>On</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1269"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Manage Tint2 Panel</source>
        <translation>Tint2 Panelini Yönet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1579"/>
        <source>Height</source>
        <translation>Yükseklik</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <location filename="../defaultlook.ui" line="1406"/>
        <source>Autohide</source>
        <translation>Otomatik gizleme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <location filename="../defaultlook.ui" line="1622"/>
        <location filename="../defaultlook.ui" line="1714"/>
        <source>Placement</source>
        <translation>Yerleştirme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1290"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Masaüstü Simgeleri&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1337"/>
        <source>Toggle icon captions</source>
        <translation>Simge altyazılarını değiştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>On Hover</source>
        <translation>Vurgulu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Toggle desktop icons</source>
        <translation>Masaüstü simgelerini değiştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1636"/>
        <location filename="../defaultlook.ui" line="1829"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Öntanımlıları Sıfırla&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Araç Çubuğu Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1361"/>
        <source>Width</source>
        <translation>Genişlik</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Show Toolbar</source>
        <translation>Araç Çubuğunu Göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1554"/>
        <source>Reset DefaultDock</source>
        <translation>Öntanımlı Sabitleyiciyi Sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Fluxbox Menüyü Sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1683"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>TÜM mx-fluxbox ayarlarını sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Varsa, mevcut fluxbox menüsüne yeni varsayılan menü öğeleri ekleyin.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>Upgrade existing menu entries</source>
        <translation>Mevcut menü girişlerini güncelle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1782"/>
        <source>Workspace</source>
        <translation>Çalışma Alanı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1822"/>
        <source>Enable single-click</source>
        <translation>Tek tıklamayı etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1836"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>KDE/Plasma öntanımlılarını sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1870"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm’yi (giriş ekranı) sistem öntanımlı temasına sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Password for administrative tasks:</source>
        <translation>Yönetici görevleri için parola:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1908"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Dahili sürücülerin root olmayan kullanıcılar tarafından bağlanmasını etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1915"/>
        <source>Root</source>
        <translation>Kök</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1922"/>
        <source>Enable kernel sandbox</source>
        <translation>Çekirdek sanal alanını etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1929"/>
        <source>&amp;User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1936"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;yeniden başlatılmalı&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1939"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Önyükleme sırasında Bluetooth Adaptörlerini etkinleştirin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1946"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt, bağımlılık olarak &quot;önerilen&quot; ek paketleri kurar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1953"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Paket yükleme, kaldırma ve güncellemelerden sonra fluxbox Tüm Uygulamalar menüsünu oluşturur</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1960"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Onları destekleyen GTK3 uygulamalarında İstemci Tarafı Dekorasyonlarını (CSD) kullanın (oturumun yeniden başlatılmasını gerektirir)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1967"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Öntanımlı &quot;modesetting&quot; sürücü yerine intel sürücüsü kullanın (yeniden başlatma gerekir)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1974"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>NOTE: mevcut /etc/X11/xorg.conf.d/20-intel.conf ev klasörüne yedeklenecek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1981"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Amd  grafik işlemcinin tearfree seçeneğini kullan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1988"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOTE: mevcut /etc/X11/xorg.conf.d/20-amd.conf ev klasörüne yedeklenecek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1995"/>
        <source>Use tearfree radeon driver option</source>
        <translation>tearfree radeon sürücü seçeneğini kullan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2002"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOTE: mevcut  /etc/X11/xorg.conf.d/20-radeon.conf ev klasörüne yedeklenecek</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--ekran anahtarı yalnızca Xfce için geçerlidir</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>About MX Tweak</source>
        <translation>MX Tweak Hakkında</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="652"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="653"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Hızlı öntanımlı kullanıcı arayüzü tema değişiklikleri ve ince ayarlar için uygulama</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="655"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="656"/>
        <source>%1 License</source>
        <translation>%1 Lisans</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="670"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="680"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Tamamlandı! Değişikliklerin etkili olması için Firefox’un yeniden başlatılması gerekebilir</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="727"/>
        <source>Plese remove special characters</source>
        <translation>Lütfen özel karakterleri silin</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="727"/>
        <source>from file name</source>
        <translation>dosya adından</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="734"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Dosya adı zaten var. Başka bir ad seç</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="762"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Dosya geçerli bir tar.xz arşiv dosyası değil</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="765"/>
        <source>Archive does not contain a panel config</source>
        <translation>Arşiv, panel yapılandırması içermiyor</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="940"/>
        <source>Panel settings</source>
        <translation>Panel ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="941"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Geçerli panel ayarlarınız, ev klasörünüzde .restore adlı gizli bir klasöre yedeklendi (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1723"/>
        <source>settings</source>
        <translation>ayarlar</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2063"/>
        <source>Choose a theme set</source>
        <translation>Bir Tema Grubu Seç</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Kullanıcı Temasını Kaldır</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Yeni Tema Takımı</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Yeni tema grubu için isim girin</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Pencere Düğmeleri</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Görünüm&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Düğme etiketlerini göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Düz düğmeleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Tanıtıcıyı göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sıralama düzeni:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Zaman Damgası</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Grup başlığı ve zaman damgası</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Pencere başlığı</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Grup başlığı ve pencere başlığı</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Hiçbiri, sürükle-bıraka izin ver</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Davranış&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Pencere gruplama:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Asla</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Daima</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Orta tıklama eylemi:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Pencereyi Kapat</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Pencereyi Küçült</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Küçültülmüş pencereyi mevcut çalışma alanına geri yükle</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Herhangi bir düğme üzerindeyken pencere çerçevesini çiz</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Pencereler arasında fare topu kullanarak geçiş yap</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtreleme&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Tüm çalışma alanlarındaki bütün pencereleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Sadece küçültülmüş pencereleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Tüm monitörlerdeki bütün pencereleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Açılır Pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Hareket halinde pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Matlık Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Pencere döşemeleri</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Sabit pencerlerin altında gölgeler göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Açılır pencerelerin altında gölgeler göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Yeniden boyutlandırma sırasında pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Normal pencerelerin altında gölge göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Özellik Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Döngü sırasında simgelerin yerine pencere önizlemesini göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Tüm ekranı kaplayan pencereyi doğrudan görüntüle</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Etkin olmayan pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Çizimi dikey boşluğa eşzamanla</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Ayarları</translation>
    </message>
</context>
</TS>
